@@ -5,8 +5,6 @@
 #include "location.h"
 #include "gpscontroller.h"
 #include "ytv.h"
-#include "messagetable.h"
-#include "messagehandler.h"
 
 #include <QDebug>
 #include <QObject>
@@ -15,7 +13,6 @@
 
 int main(int argc, char *argv[] )
 {
-  qInstallMsgHandler( messageHandler );
   QApplication app(argc, argv);
 
   QMainWindow *mainWindow = new QMainWindow;
@@ -47,8 +44,8 @@ int main(int argc, char *argv[] )
     );
 
   QObject::connect(
-      ui, SIGNAL( fakeGpsPressed( Location* ) ),
-      gpsController, SLOT( useFakeGps( Location* ) )
+      ui, SIGNAL( fakeGpsPressed( const QString & ) ),
+      gpsController, SLOT( useFakeGps( const QString & ) )
     );
 
   QObject::connect(
@@ -56,6 +53,11 @@ int main(int argc, char *argv[] )
       gpsController, SLOT( useLiveGps() )
     );
 
+  QObject::connect(
+      route, SIGNAL( busy( bool ) ),
+      ui, SLOT( setBusy( bool ) )
+    );
+
   mainWindow->show();
 
   return app.exec();
